@@ -1,4 +1,4 @@
-/* $Header: /local/src/CVS/nickle/array.c,v 1.25 2004/04/16 06:06:01 keithp Exp $ */
+/* $Header: /local/src/CVS/nickle/array.c,v 1.28 2004/12/18 07:12:40 keithp Exp $ */
 
 /*
  * Copyright © 1988-2004 Keith Packard and Bart Massey.
@@ -7,6 +7,7 @@
  */
 
 #include	"nickle.h"
+#include    	"gram.h"
 
 int
 ArrayInit (void)
@@ -360,6 +361,7 @@ ArrayResize (Value av, int dim, int size)
 	    /* empty */
 	    ents = 0;
 	    nstride = 0;
+	    odim = 0;
 	    size = 0;
 	    nchunk = 0;
 	    for (d = 0; d < a->ndim; d++)
@@ -420,3 +422,35 @@ ArraySetDimensions (Value av, int *dims)
     for (i = 0; i < a->ndim; i++)
 	ArrayResize (av, i, dims[i]);
 }
+
+Type *
+BuildArrayType (Type *subtype, int ndim, ...)
+{
+    ENTER ();
+    Expr    *dims = 0;
+    int	    i;
+    int	    dim;
+    va_list ap;
+    Type    *type;
+    Value   dimArray;
+
+    dimArray = NewArray (True, False, typePrim[rep_integer], 1, &ndim);
+    va_start (ap, ndim);
+    for (i = 0; i < ndim; i++)
+    {
+	dim = va_arg (ap, int);
+	ArrayValueSet(&dimArray->array, i, NewInt (dim));
+	dims = NewExprTree (COMMA, NewExprConst (TEN_FLOAT, NewInt (dim)),
+			    dims);
+    }
+    va_end (ap);
+    type = NewTypeArray (subtype, dims, False);
+    /*
+     * Create an array to hold the dimension information and
+     * fill it in
+     */
+    type->array.storage = DimStorageGlobal;
+    type->array.u.global = NewBox (True, False, 1, typeArrayInt);
+    BoxValueSet (type->array.u.global, 0, dimArray);
+    RETURN (type);
+}
