@@ -1,4 +1,4 @@
-/* $Header: /local/src/CVS/nickle/builtin-toplevel.c,v 1.28 2004/11/23 05:02:07 bart Exp $ */
+/* $Header: /local/src/CVS/nickle/builtin-toplevel.c,v 1.29 2005/01/14 05:44:00 keithp Exp $ */
 
 /*
  * Copyright © 1988-2004 Keith Packard and Bart Massey.
@@ -485,7 +485,7 @@ do_setdims (Value av, Value dv)
     for (i = 0; i < a->ndim; i++)
     {
 	int j = a->ndim - 1 - i;
-	dims[j] = IntPart (ArrayValueGet (d,i), "setdims: invalid dimension");
+	dims[j] = IntPart (ArrayValue (d,i), "setdims: invalid dimension");
 	if (aborting)
 	    RETURN (Void);
 	if (dims[j] < 0)
