@@ -1,4 +1,4 @@
-/* $Header: /local/src/CVS/nickle/builtin.h,v 1.9 2004/06/08 09:30:53 keithp Exp $ */
+/* $Header: /local/src/CVS/nickle/builtin.h,v 1.12 2004/12/17 02:05:20 keithp Exp $ */
 
 /*
  * Copyright © 1988-2004 Keith Packard and Bart Massey.
@@ -12,7 +12,11 @@
  *	header shared across builtin implementation source files
  */
 
+#if LOCAL_BUILD
 #include	"nickle.h"
+#else
+#include	<nickle/nickle.h>
+#endif
 
 SymbolPtr
 BuiltinAddName (NamespacePtr	*namespacep,
@@ -27,6 +31,9 @@ SymbolPtr
 BuiltinNamespace (NamespacePtr  *namespacep,
 		  char		*string);
 
+void
+BuiltinSetUserdefType (Type *type, int n);
+
 SymbolPtr
 BuiltinException (NamespacePtr  *namespacep,
 		  char		*string,
@@ -47,6 +54,47 @@ BuiltinAddException (NamespacePtr	*namespacep,
 		     char		*format,
 		     char		*doc);
 
+struct sbuiltin {
+    char	    *value;
+    char	    *name;
+    NamespacePtr    *namespace;
+};
+
+#define BuiltinStrings(s) do { \
+    SymbolPtr	sym; const struct sbuiltin *si; \
+    for (si = (s); si->name; si++) { \
+	sym = BuiltinSymbol (si->namespace, si->name, typePrim[rep_string]); \
+	BoxValueSet (sym->global.value, 0, NewStrString (si->value)); \
+    } } while (0)
+
+struct envbuiltin {
+#ifdef CENVIRON
+    char	    *var;
+#endif
+    char	    *def;
+    char	    *name;
+    NamespacePtr    *namespace;
+};
+    
+struct ibuiltin {
+    int		    value;
+    char	    *name;
+    NamespacePtr    *namespace;
+};
+
+#define BuiltinIntegers(s) do { \
+    SymbolPtr	sym; const struct ibuiltin *ii; \
+    for (ii = (s); ii->name; ii++) { \
+	sym = BuiltinSymbol (ii->namespace ,ii->name, typePrim[rep_integer]); \
+	BoxValueSet (sym->global.value, 0, Reduce (NewIntInteger (ii->value))); \
+    } } while (0)
+
+struct filebuiltin {
+    char	    *name;
+    Value   	    *value;
+    NamespacePtr    *namespace;
+};
+
 void
 BuiltinAddFunction (NamespacePtr *namespacep, char *name, char *ret_format,
 		    char *format, BuiltinFunc f, Bool jumping, char *doc);
@@ -137,4 +185,8 @@ BuiltinFuncStructDef(fbuiltin_2j, fbuiltin_2j_func);
 #define BuiltinFuncs2J(n, f) \
 	BuiltinFuncsGeneric(n, f, fbuiltin_2j, builtin2J, True)
 
+#if LOCAL_BUILD
 #include "builtin-namespaces.h"
+#else
+#include <nickle/builtin-namespaces.h>
+#endif
