@@ -1,4 +1,4 @@
-/* $Header: /local/src/CVS/nickle/execute.c,v 1.94 2004/12/11 06:02:23 keithp Exp $ */
+/* $Header: /local/src/CVS/nickle/execute.c,v 1.95 2005/01/14 05:44:00 keithp Exp $ */
 
 /*
  * Copyright © 1988-2004 Keith Packard and Bart Massey.
@@ -348,7 +348,7 @@ ThreadArrayInd (Value thread, Bool resizable, Value dim, Type *type)
     dims = AllocateTemp (ndim * sizeof (int));
     for (i = 0; i < ndim; i++)
     {
-	Value	d = ArrayValueGet(a, i);
+	Value	d = ArrayValue (a, i);
 	dims[i] = IntPart (d, "Invalid array dimension");
 	if (dims[i] < 0)
 	    RaiseStandardException (exception_invalid_argument,
