@@ -1,4 +1,4 @@
-/* $Header: /local/src/CVS/nickle/float.c,v 1.27 2004/12/17 05:49:33 keithp Exp $ */
+/* $Header: /local/src/CVS/nickle/float.c,v 1.28 2005/01/14 05:44:00 keithp Exp $ */
 
 /*
  * Copyright © 1988-2004 Keith Packard and Bart Massey.
@@ -1163,6 +1163,12 @@ DoublePart (Value av, char *error)
     double  div;
     
     av = NewValueFloat (av, 64);
+    if (!ValueIsFloat (av))
+    {
+	RaiseStandardException (exception_invalid_argument, error, 
+				2, NewInt (0), av);
+	return 0.0;
+    }
     if (NaturalLess (av->floats.exp->mag, max_int_natural))
 	e = NaturalToInt (av->floats.exp->mag);
     else
