@@ -1,4 +1,4 @@
-/* $Header: /local/src/CVS/nickle/main.c,v 1.37 2004/04/16 05:26:45 keithp Exp $ */
+/* $Header: /local/src/CVS/nickle/main.c,v 1.39 2004/12/09 23:27:13 keithp Exp $ */
 
 /*
  * Copyright © 1988-2004 Keith Packard and Bart Massey.
@@ -12,13 +12,22 @@
  *	main routine for nick
  */
 
+#include	"nickle.h"
+#include	"gram.h"
+
 #include	<setjmp.h>
 #define __USE_UNIX98 /* Get sigignore() and sigrelse()
 			prototype for Linux */
 #include	<signal.h>
 #include	<stdio.h>
-#include	"nickle.h"
-#include	"gram.h"
+
+#if HAVE_SYS_TIME_H
+#include	<sys/time.h>
+#endif
+
+#if HAVE_SYS_RESOURCE_H
+#include	<sys/resource.h>
+#endif
 
 int	stdin_interactive;
 
@@ -65,6 +74,20 @@ releaseSignal(int sig) {
 int
 main (int argc, char **argv)
 {
+#if HAVE_GETRLIMIT && HAVE_SETRLIMIT
+    /*
+     * Allow stack to grow as large as possible to avoid
+     * crashes during recursive datastructure marking in the
+     * garbage collector
+     */
+    struct rlimit   lim;
+
+    if (getrlimit (RLIMIT_STACK, &lim) == 0)
+    {
+	lim.rlim_cur = lim.rlim_max;
+	(void) setrlimit (RLIMIT_STACK, &lim);
+    }
+#endif
     (void) catchSignal (SIGHUP, die);
     (void) catchSignal (SIGINT, intr);
     (void) catchSignal (SIGQUIT, die);
