@@ -1,4 +1,4 @@
-/* $Header: /local/src/CVS/nickle/nickle.h,v 1.119 2004/06/17 20:30:47 keithp Exp $ */
+/* $Header: /local/src/CVS/nickle/nickle.h,v 1.121 2004/12/11 06:02:23 keithp Exp $ */
 
 /*
  * Copyright © 1988-2004 Keith Packard and Bart Massey.
@@ -6,9 +6,17 @@
  * for licensing information.
  */
 
+#if LOCAL_BUILD
 #include	"config.h"
+#include	"mem.h"
 #include	"value.h"
 #include	"opcode.h"
+#else
+#include	<nickle/config.h>
+#include	<nickle/mem.h>
+#include	<nickle/value.h>
+#include	<nickle/opcode.h>
+#endif
 #include	<assert.h>
 
 typedef struct _func	    *FuncPtr;
@@ -598,6 +606,15 @@ void	    ThreadInit (void);
 void	    TraceFunction (Value file, FramePtr frame, CodePtr code, ExprPtr name);
 void	    TraceFrame (Value file, FramePtr frame, ObjPtr obj, InstPtr pc, int depth);
 void	    ThreadStackDump (Value thread);
+void	    ThreadsBlock (void);
+
+typedef void	(*NickleBlockHandler) (void *closure);
+
+void
+ThreadsRegisterBlockHandler (NickleBlockHandler handler, void *closure);
+
+void
+ThreadsUnregisterBlockHandler (NickleBlockHandler handler, void *closure);
 
 typedef struct _jump {
     DataType	    *data;
@@ -987,6 +1004,7 @@ Value	do_is_func (Value);
 Value	do_is_bool (Value);
 Value	do_is_void (Value);
 Value	do_is_uninit (Value);
+Value	do_make_uninit (Value);
 Value	do_hash (Value);
 Value	do_Thread_get_priority (Value);
 Value	do_Thread_id_to_thread (Value);
